@@ -5,7 +5,7 @@ import simplejson as json
 import pytz
 
 from jinja2 import TemplateNotFound
-from flask import request, Response, abort
+from flask import g, request, Response, abort
 from flask.ext.routes import route
 
 from .view import View
@@ -126,6 +126,13 @@ class ModelView(View):
         return self.do_archive(id)
 
 
+    # ACTIONS (ROUTES + IMPLEMENTATIONS) ---------------------------------------
+    @route('/set-continue', methods=('POST',))
+    def set_continue(self):
+        self.session['continue'] = request.form.get('value', 'edit')
+        return Response(status=204)
+
+
     # IMPLEMENTATIONS ----------------------------------------------------------
     def do_index(self, index):
         if not self.allows(index):
@@ -268,13 +275,13 @@ class ModelView(View):
         )
 
 
-    @route('/set-continue', methods=('POST',))
-    def set_continue(self):
-        self.session['continue'] = request.form.get('value', 'edit')
-        return Response(status=204)
-
-
     # HELPERS ------------------------------------------------------------------
+    def allows(self, action, models=[], with_filters=True):
+        return g.user.allowed(
+            '{}.{}'.format(self.endpoint, action), models, with_filters=with_filters
+        )
+
+
     def autoredirect(self, model_id):
         _continue = self.session.get('continue', 'edit')
         if _continue == 'edit':
