@@ -1,5 +1,5 @@
 from functools import partial
-from flask import url_for, redirect, session, Blueprint
+from flask import url_for, redirect, session, Blueprint, render_template
 
 
 class View:
@@ -40,3 +40,10 @@ class View:
             return partial(url_for, '{self.endpoint}:{endpoint}'.format(
                 self=self, endpoint=endpoint), **values
             )
+
+
+    def render(self, template_name, **context):
+        if '.' not in template_name:
+            template_name = self.templates[template_name]
+        context['view'] = self
+        return render_template(template_name, **context)
